Documentation
¶
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Notations ¶
func Extract ¶
Returns the Notations extracted from the text, uses the distics chars as notation indetifier.
Example ¶
txt := `@username assume this is a reply, by @anotherusername that has
some #tag1 and #tag2. It also works the same way for %any &other *symbol,
but you provably will only use things like $2377.12.`
notationsMap := notations.Extract(txt, "@#$%&*$")
for key, notations := range notationsMap {
fmt.Printf("%s: ", key)
for _, notation := range notations {
fmt.Printf("%s ", notation.Value)
}
fmt.Println("")
}
Output: @: username anotherusername #: tag1 tag2 %: any &: other *: symbol $: 2377.12
Click to show internal directories.
Click to hide internal directories.